@@ -11,14 +11,14 @@ from pytconf.config import register_endpoint, register_function_group
 import pyscrapers.core.utils
 import pyscrapers.version
 from pyscrapers.configs import ConfigDebugRequests, ConfigCookiesSource, ConfigSiteId, ConfigPornhubSearch, \
-    ConfigYoutubeDl, ConfigPornhubDownload, ConfigPornhubPornstar, ConfigDownload, ConfigLogging
+    ConfigYoutubeDl, ConfigDownload, ConfigLogging, ConfigPornhubUrl
 from pyscrapers.core.url_set import UrlSet
 from pyscrapers.workers.drumeo import get_number_of_pages, get_courses, get_course_details, get_course_urls, \
     download_course
 from pyscrapers.workers.facebook import scrape_facebook
 from pyscrapers.workers.instagram import scrape_instagram
 from pyscrapers.workers.mambaru import scrape_mambaru
-from pyscrapers.workers.pornhub import download, print_stars_all_detailed, pornhub_download_pornstar_handler
+from pyscrapers.workers.pornhub import download_search, print_stars_all_detailed, download_url
 from pyscrapers.workers.travelgirls import scrape_travelgirls
 from pyscrapers.workers.vk import scrape_vk
 from pyscrapers.workers.youtube_dl_handlers import youtube_dl_handler
@@ -39,7 +39,6 @@ def register_group_default():
 
 @register_endpoint(
     configs=[],
-    suggest_configs=[],
     group=GROUP_NAME_DEFAULT,
 )
 def version() -> None:
@@ -57,7 +56,6 @@ def version() -> None:
         ConfigDownload,
         ConfigLogging,
     ],
-    suggest_configs=[],
     group=GROUP_NAME_DEFAULT,
 )
 def photos():
@@ -91,7 +89,6 @@ def photos():
         ConfigDebugRequests,
         ConfigCookiesSource,
     ],
-    suggest_configs=[],
     group=GROUP_NAME_DEFAULT,
 )
 def drumeo():
@@ -133,24 +130,8 @@ def drumeo():
     session.close()
 
 
-@register_endpoint(
-    configs=[
-        ConfigPornhubSearch,
-        ConfigPornhubDownload,
-    ],
-    suggest_configs=[],
-    group=GROUP_NAME_DEFAULT,
-)
-def pornhub():
-    """
-    Download movies from pornhub
-    """
-    download()
-
-
 @register_endpoint(
     configs=[],
-    suggest_configs=[],
     group=GROUP_NAME_DEFAULT,
 )
 def pornhub_stars_all_detailed():
@@ -161,11 +142,40 @@ def pornhub_stars_all_detailed():
     print_stars_all_detailed(api)
 
 
+@register_endpoint(
+    configs=[
+        ConfigPornhubSearch,
+        ConfigDownload,
+    ],
+    group=GROUP_NAME_DEFAULT,
+)
+def pornhub_download_search():
+    """
+    Download search results from pornhub
+    """
+    download_search()
+
+
+@register_endpoint(
+    configs=[
+        ConfigDebugRequests,
+        ConfigCookiesSource,
+        ConfigPornhubUrl,
+        ConfigDownload,
+    ],
+    group=GROUP_NAME_DEFAULT,
+)
+def pornhub_download_url():
+    """
+    Download url videos from pornhub
+    """
+    download_url()
+
+
 @register_endpoint(
     configs=[
         ConfigYoutubeDl,
     ],
-    suggest_configs=[],
     group=GROUP_NAME_DEFAULT,
 )
 def youtube_dl():
@@ -173,20 +183,3 @@ def youtube_dl():
     Download movies from pornhub
     """
     youtube_dl_handler()
-
-
-@register_endpoint(
-    configs=[
-        ConfigDebugRequests,
-        ConfigCookiesSource,
-        ConfigPornhubPornstar,
-        ConfigPornhubDownload,
-    ],
-    suggest_configs=[],
-    group=GROUP_NAME_DEFAULT,
-)
-def pornhub_download_pornstar():
-    """
-    Download movies of a pornstar from pornhub
-    """
-    pornhub_download_pornstar_handler()
